=====================
Locust Documentation
=====================

.. sidebar:: About locust

    Locust is a scalable load testing framework written in Python

    * **Website**: `https://locust.io/ <https://locust.io/>`_
    * **Source code**: `https://github.com/locustio/locust <https://github.com/locustio/locust>`_
    * **Twitter**: `@locustio <https://twitter.com/locustio>`_


Getting started
---------------

.. toctree ::
    :maxdepth: 2

    what-is-locust
    installation
    quickstart


Writing Locust tests
--------------------

.. toctree ::
    :maxdepth: 2

    writing-a-locustfile


Running your Locust tests
-------------------------

.. toctree ::
    :maxdepth: 1

    configuration
    running-distributed
    running-in-debugger
    running-in-docker
    running-cloud-integration
    running-without-web-ui


Other functionalities
---------------------

.. toctree ::
    :maxdepth: 2

    custom-load-shape
    retrieving-stats
    testing-other-systems
    increase-performance
    extending-locust
    logging
    use-as-lib


Further reading / knowledgebase
-------------------------------

.. toctree ::
    :maxdepth: 1

    developing-locust
    further-reading


API
---
.. toctree ::
    :maxdepth: 4

    api



Changelog
---------

.. toctree ::
    :maxdepth: 2

    changelog
